Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mumble-voip/mumble.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMikkel Krautz <mikkel@krautz.dk>2016-08-04 03:24:11 +0300
committerMikkel Krautz <mikkel@krautz.dk>2016-08-04 03:24:11 +0300
commit8ee2bbc51c461a42a3a6edfee6c7cee607930b17 (patch)
tree59e01685f0e92e85121cc398ec89d1159b2c1f18 /3rdparty
parent2f886052e4232905ea3c2cb5c027cac8a3ba72c2 (diff)
3rdparty/xinputcheck-src: add Xbox One controller GUIDs to avoid device list querying for Xbox One controllers.
Querying the device list and checking whether IG_ is in the name does not work on Windows 10 Anniversary Update (1607). To work around that, we add the GUIDs for all Xbox One controllers. This should fix the problem for the most common XInput devices for now. Presumably, Microsoft will fix this later on. But for now, this will do. The good thing about doing it this way is that it isn't a workaround per se -- it's an optimization that already exists in the code. Fixes mumble-voip/mumble#2483
Diffstat (limited to '3rdparty')
-rw-r--r--3rdparty/xinputcheck-src/xinputcheck.cpp10
1 files changed, 8 insertions, 2 deletions
diff --git a/3rdparty/xinputcheck-src/xinputcheck.cpp b/3rdparty/xinputcheck-src/xinputcheck.cpp
index 8cefb0d17..ebd7ed4d2 100644
--- a/3rdparty/xinputcheck-src/xinputcheck.cpp
+++ b/3rdparty/xinputcheck-src/xinputcheck.cpp
@@ -76,11 +76,17 @@ SDL_IsXInputDevice(const GUID* pGuidProductFromDirectInput)
static GUID IID_ValveStreamingGamepad = { MAKELONG(0x28DE, 0x11FF), 0x0000, 0x0000, { 0x00, 0x00, 0x50, 0x49, 0x44, 0x56, 0x49, 0x44 } };
static GUID IID_X360WiredGamepad = { MAKELONG(0x045E, 0x02A1), 0x0000, 0x0000, { 0x00, 0x00, 0x50, 0x49, 0x44, 0x56, 0x49, 0x44 } };
static GUID IID_X360WirelessGamepad = { MAKELONG(0x045E, 0x028E), 0x0000, 0x0000, { 0x00, 0x00, 0x50, 0x49, 0x44, 0x56, 0x49, 0x44 } };
+ static GUID IID_XOneWiredGamepad = { MAKELONG(0x045E, 0x02FF), 0x0000, 0x0000, { 0x00, 0x00, 0x50, 0x49, 0x44, 0x56, 0x49, 0x44 } };
+ static GUID IID_XOneWirelessGamepad = { MAKELONG(0x045E, 0x02DD), 0x0000, 0x0000, { 0x00, 0x00, 0x50, 0x49, 0x44, 0x56, 0x49, 0x44 } };
+ static GUID IID_XOneBluetoothGamepad = { MAKELONG(0x045E, 0x02E0), 0x0000, 0x0000, { 0x00, 0x00, 0x50, 0x49, 0x44, 0x56, 0x49, 0x44 } };
static const GUID *s_XInputProductGUID[] = {
&IID_ValveStreamingGamepad,
- &IID_X360WiredGamepad, /* Microsoft's wired X360 controller for Windows. */
- &IID_X360WirelessGamepad /* Microsoft's wireless X360 controller for Windows. */
+ &IID_X360WiredGamepad, /* Microsoft's wired X360 controller for Windows. */
+ &IID_X360WirelessGamepad, /* Microsoft's wireless X360 controller for Windows. */
+ &IID_XOneWiredGamepad, /* Microsoft's wired Xbox One controller for Windows. */
+ &IID_XOneWirelessGamepad, /* Microsoft's wireless Xbox One controller for Windows. */
+ &IID_XOneBluetoothGamepad /* Microsoft's Bluetooth Xbox One controller for Windows. */
};
size_t iDevice;